package com.zswl.cloud.springBtach.server.core.publish;

import com.github.microservice.productcenter.client.model.LocationModel;
import com.github.microservice.productcenter.client.model.ProductPushModel;
import com.github.microservice.productcenter.client.model.ProductTriggerTaskModel;
import com.github.microservice.productcenter.client.model.RegionModel;
import com.github.microservice.productcenter.client.publish.ProductPublish;
import com.github.microservice.productcenter.client.service.ProductPushService;
import com.github.microservice.productcenter.client.type.ProductType;
import com.github.microservice.productcenter.client.type.RegionType;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.request.ScenicListRequest;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.ScenicListResponse;
import com.zswl.cloud.springBtach.server.core.api.dfy.TicketApi;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

@Slf4j
@Component
public class TicketPublish implements ProductPublish {

    @Autowired
    TicketApi ticketApi;

    @Override
    public String regionCode() {
        return null;
    }

    @Override
    public Collection<RegionType> regionType() {
        return Set.of(RegionType.City);
    }

    @Override
    public Collection<ProductType> productTypes() {
        return Set.of(
                ProductType.Scenic
        );
    }


    @Override
    public void trigger(ProductPushService updateService, ProductTriggerTaskModel productTriggerTask) {


        RegionModel region = productTriggerTask.getRegion();
        String name = region.getName();

        int page = 1;
        while (true) {
            ScenicListRequest scenicListRequest = new ScenicListRequest();
            scenicListRequest.setPage(page);
            scenicListRequest.setPageSize(10);
            scenicListRequest.setKey(name);
            ScenicListResponse scenicListResponse = ticketApi.scenicList(scenicListRequest);

            List<ScenicListResponse.rows> rows = scenicListResponse.getData().getRows();

            if (rows.isEmpty()) {
                return;
            }
            List<ProductPushModel> scenic = rows.stream().parallel().map(it -> {
                System.out.println(it);
                LocationModel locationModel = new LocationModel();
                String glocation = it.getGlocation();
                if (!glocation.isEmpty()) {
                    String[] split = glocation.split(",");

                    locationModel.setLatitude(Double.parseDouble(split[0]));
                    locationModel.setLongitude(Double.parseDouble(split[1]));
                }

                return ProductPushModel.builder()
                        .regionCode(productTriggerTask.getRegion().getCode())
                        .pid(it.getScenicId())
                        .productType(ProductType.Scenic)
                        .cover(new String[]{it.getNewPicUrl()})
                        .title(it.getScenicName())
                        .meta(Map.of("scenic", it))
                        .locationPoint(locationModel)
                        .build();
            }).collect(Collectors.toList());

            updateService.push(scenic);

            page++;

        }


    }
}
